Class: Rutema::ErrorMessage

Inherits:
Message
  • Object
show all
Defined in:
lib/rutema/core/framework.rb

Overview

Message container to report test errors

The reported on errors may concern the test specifications, parser errors or errors which occurred during test execution. Logic errors of rutema itself are not reported by means of this class.

Instance Attribute Summary

Attributes inherited from Message

#test, #text, #timestamp

Instance Method Summary collapse

Methods inherited from Message

#initialize

Constructor Details

This class inherits a constructor from Rutema::Message

Instance Method Details

#to_sObject

Convert the instance to a convenient textual representation



61
62
63
64
65
66
# File 'lib/rutema/core/framework.rb', line 61

def to_s
  msg = "ERROR - "
  msg << "#{@test} " unless @test.empty?
  msg << @text
  return msg
end