Module: Rutema::Parsers
- Defined in:
- lib/rutema/core/parser.rb,
lib/rutema/parsers/xml.rb
Overview
Module for the definition of classes for the parsing of test specifications
Defined Under Namespace
Classes: SpecificationParser, XML
Module for the definition of classes for the parsing of test specifications
Classes: SpecificationParser, XML