Module: Rutema::Reporters

Defined in:
lib/rutema/core/reporter.rb,
lib/rutema/reporters/json.rb,
lib/rutema/reporters/junit.rb

Overview

Module for the definition of reporter classes

rutema supports two kinds of reporters. Reporters derived from BlockReporter are supposed to receive data via the #report method at the end of a Rutema run. Reporters derived from EventReporter are intended to receive events continuously during a run via the #update method.

Nothing permits implementing a reporter class which supports both behaviours.

Defined Under Namespace

Classes: BlockReporter, Collector, Console, EventReporter, JSON, JUnit, Summary